#!/usr/bin/python
# -*- coding: utf-8 -*-
# filename: /usr/bin/faxgate.py
#
# function: test if this user is allowed to send faxes,
#           send textmails and send messges via networksockets
#
# Author: Ingo Goeppert <ingo.goeppert@gmx.de>
# Version: 0.14 from Mo Mai 28 10:02:40 2007
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# import system-functions
import getopt,os,sys,pwd

# import capisuite functions
import cs_helpers

# default settings
user=""
mail=""
ip=""
port=""
command=""
m_from=""
m_to=""
m_subject=""
m_body=""

# function for error msg
def usage(error=""):
   if (error!=""):
      print "DEBUG: faxgate.py: ",error
   print ""
   print """faxgate.py - tool for cups-faxgate-backend

usage:
faxgate.py -u <user>, --user=<user> or
faxgate.py -m -f <address> -t <address> -s <subject> -b <body> or
faxgate.py -u <user> -i <ip> -p <port> -c <command> or
faxgate.py -h, --help for this help

possible options are:
-u <user>, --user=<user>
check if <user> is allowed to send faxes (only when called as root!)
or
-m --mail
send mail to -t <address>, --to=<address> from -f <address>, --from=<address>
with subject -s <subject>, --subject=<subject> and body -b <body>, --body=<body>
or
send command -c <command>, --command=<command> to host -i <hostname or ip>,
--ip=<hostname or ip> on port -p <port>, --port=<port> if
-u <user>, --user <user> wan't the message and get answer as returnvalue."""
   sys.exit(2)

# check if user is a valid faxuser in the capisuite config files
def checkUser(user):
   config=cs_helpers.readConfig()
   # if no user argument, use systemuser
   if (user==""):
      user=pwd.getpwuid(os.getuid())[0]
   # if no section found in config, exit
   if (not config.has_section(user)):
      sys.exit(2)
   # here the user is in config, is there a valid fax config for the user?
   if ((cs_helpers.getOption(config,user,"outgoing_MSN","")=="") and (config.get(user,"fax_numbers","")=="")):
      sys.exit(2)
   else:
      # user is allowed to fax
      # search for the maildress
      mailaddress=cs_helpers.getOption(config,user,"fax_email","")
      if (mailaddress==""):
         mailaddress=user
      # print it for the backend
      print mailaddress
      sys.exit(0)

# send a simple mail
def sendMail(mail_from,mail_to,mail_subject,text):
   cs_helpers.sendSimpleMail(mail_from,mail_to,mail_subject,text,False)

# main function:
# read the arguments from commandline
try:
   optlist,args = getopt.getopt(sys.argv[1:], "u:mf:t:s:b:hi:p:c:",["user=", "mail", "from=", "to=", "subject=", "body=", "help", "ip=", "port=", "command="])

# print usage if reading fails
except getopt.GetoptError, e:
   usage(e.msg)

# read options
for option,param in optlist:
   if option in ('-m','--mail'): mail="true"
   if option in ('-i','--ip'): ip=param
   if option in ('-p','--port'): port=param
   if option in ('-c','--command'): command=param
   if option in ('-f','--from'): m_from=param
   if option in ('-t','--to'): m_to=param
   if option in ('-s','--subject'): m_subject=param
   if option in ('-b','--body'): m_body=param
   if option in ('-h','--help'): usage()
   if option in ('-u','--user'):
      if (os.getuid()==0):
         user=param
      else:
         usage("--user may only used as root!")

# check if correct command is given
if (not user and not (m_from and m_to and m_subject and m_body and mail) and not (user and ip and port and command)):
   usage("No usable command given.")
   sys.exit(2)

# if mail argument given
if (mail):
   sendMail(m_from,m_to,m_subject,m_body)
   sys.exit(0)

# if ip argument given open networkconnection
if (ip):
   config=cs_helpers.readConfig()
   fax_client_messages=cs_helpers.getOption(config,user,"fax_client_messages","")
   # Faxmaster-Hack, he wan't always messages
   if (user=="Faxmaster"):
      fax_client_messages="yes"
   if (fax_client_messages=="yes"):
      data=cs_helpers.netconnect(ip, port, command[10:200], command[0:8])
      if (data[0:2]=="Nu"):
         print data[8:50]
         sys.exit(0)
      print "DEBUG: faxgate.py: "+data
      sys.exit(2)
   print "DEBUG: faxgate.py: User "+user+" nicht fuer Faxgate Client Verbindungen konfiguriert."
   sys.exit(2)

# if user argument given
if (user):
   checkUser(user)
   sys.exit(0)

# end of main
sys.exit(0)
